Dokumente: BDEW Forum Datenformate

Skip to main content

## Aktuell gültige Dokumente

nach Gruppierung
Listenansicht

Titel | Gültig von | Gültig bis |
--- | --- | --- | ---
Berichte
IFTSTA MIG 2.0 | 01.12.2019 | 31.03.2021 |
IFTSTA MIG 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 31.03.2021 |
IFTSTA AHB 2.0 | 01.12.2019 | 31.03.2021 |
IFTSTA AHB 2.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 31.03.2021 |
INSRPT MIG 1.1 | 01.12.2019 | Offen |
INSRPT AHB 1.1f | 01.12.2019 | Offen |
INSRPT AHB 1.1f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | Offen |
Bestellvorgang
ORDERS MIG 1.1k | 01.04.2020 | 31.03.2021 |
ORDRSP MIG 1.1h | 01.12.2019 | 31.03.2021 |
ORDRSP MIG 1.1h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 11.11.2019 | 01.12.2019 | 31.03.2021 |
ORDERS / ORDRSP AHB MaBiS 2.0a | 01.04.2020 | 31.03.2021 |
QUOTES MIG 1.1a | 01.12.2019 | 31.03.2021 |
QUOTES MIG 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 31.03.2021 |
REQOTE MIG 1.1c | 01.12.2019 | 31.03.2021 |
REQOTE / QUOTES / ORDERS / ORDRSP AHB 1.0a | 01.04.2020 | 31.03.2021 |
Bewegungsdaten
MSCONS MIG 2.3 | 01.12.2019 | 31.03.2021 |
MSCONS MIG 2.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | 31.03.2021 |
MSCONS AHB 2.3a | 01.04.2020 | 31.03.2021 |
MSCONS AHB 2.3a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.09.2020 | 30.09.2020 | 31.03.2021 |
Codelisten
Artikelnummernliste des BDEW 4.1h | 01.10.2020 | Offen |
Codeliste der europäischen Ländercodes 1.0 | 01.10.2017 | Offen |
Codeliste der europäischen Ländercodes 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2019 | 30.01.2019 | Offen |
Codeliste der OBIS-Kennzahlen 2.2h | 01.12.2019 | Offen |
Codeliste der OBIS-Kennzahlen 2.2h Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 17.12.2019 | 17.12.2019 | Offen |
Codeliste der Standardlastprofile nach TU München-Verfahren 1.1 | 01.10.2015 | Offen |
Codeliste der Standardlastprofile nach TU München-Verfahren 1.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 22.05.2015 | 01.10.2015 | Offen |
Codeliste der Statuszusatzinformation 1.1 | 01.12.2019 | Offen |
Codeliste der Temperaturanbieter 1.0h | 03.04.2020 | Offen |
Codeliste der Zeitreihentypen 1.1c | 01.12.2019 | Offen |
Codeliste der Zeitreihentypen 1.1c Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | Offen |
Datenaustausch zu Behörden
Herkunftsnachweisregister AHB 2.2a | 01.04.2020 | 31.03.2021 |
Formatübergreifende Dokumente
Allgemeine Festlegungen 4.6 | 01.12.2019 | 31.03.2021 |
Anwendungsübersicht der Prüfidentifikatoren 1.3 | 01.10.2020 | 31.03.2021 |
Anwendungsübersicht der Prüfidentifikatoren 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.07.2020 | 01.10.2020 | 31.03.2021 |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 1.3 | 28.05.2020 | Offen |
EDI@Energy Anwendungshilfe zu den Datenformaten der Marktkommunikation 2020 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 28.10.2020 | 28.10.2020 | Offen |
Entscheidungsbaum-Diagramme 1.0 | 01.10.2017 | 31.03.2021 |
Entscheidungsbaum-Diagramme 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.01.2019 | 01.10.2017 | 31.03.2021 |
Entscheidungsbaum-Diagramme 2.1 | 01.04.2020 | 31.03.2021 |
Entscheidungsbaum-Diagramme 2.1 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 31.03.2021 |
Änderungsantrag EBD 1.0 | 01.12.2019 | Offen |
Gruppierungen der EDI@Energy Dokumente 1.0a | 01.12.2019 | Offen |
Regelungen zum Übertragungsweg 1.3 | 01.10.2020 | Offen |
Regelungen zum Übertragungsweg 1.3 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.09.2020 | 01.10.2020 | Offen |
KWEP 1
Acknowledgement 1.0a | 01.04.2015 | Offen |
Acknowledgement 1.0a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | Offen |
Planned Resource Schedule 1.0 | 01.10.2014 | Offen |
Unavailability Market 1.0 | 01.04.2015 | Offen |
Unavailability Market 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.03.2015 | 01.04.2015 | Offen |
Rechnungsstellung
COMDIS MIG 1.0 | 01.12.2019 | 31.03.2021 |
COMDIS MIG 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 31.03.2021 |
COMDIS AHB 1.0 | 01.12.2019 | 31.03.2021 |
COMDIS AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 15.07.2019 | 01.12.2019 | 31.03.2021 |
INVOIC MIG 2.7 | 01.10.2020 | Offen |
INVOIC MIG 2.7 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 01.10.2020 | Offen |
INVOIC / REMADV AHB 2.4 | 01.10.2020 | Offen |
INVOIC / REMADV AHB 2.4 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 01.07.2020 | 01.10.2020 | Offen |
PRICAT MIG 1.1a | 01.12.2019 | 31.03.2021 |
PRICAT AHB 1.0a | 01.12.2019 | 31.03.2021 |
REMADV MIG 2.8 | 01.12.2019 | Offen |
Servicenachrichten
APERAK MIG 2.1d | 01.12.2019 | 31.03.2021 |
CONTRL MIG 2.0a | 01.12.2019 | Offen |
APERAK / CONTRL AHB 2.3f | 01.12.2019 | 31.03.2021 |
APERAK / CONTRL AHB 2.3f Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
Stammdaten
UTILMD MIG 5.2a | 01.04.2020 | 31.03.2021 |
UTILMD MIG 5.2a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 03.04.2020 | 03.04.2020 | 31.03.2021 |
UTILMD AHB Einspeiser 2.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB Einspeiser 2.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
UTILMD AHB GPKE / GeLi Gas 6.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB GPKE / GeLi Gas 6.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
UTILMD AHB MaBiS 3.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB MaBiS 3.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
UTILMD AHB Netzbetreiberwechsel 1.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB Netzbetreiberwechsel 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
UTILMD AHB Stammdatenänderung 1.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB Stammdatenänderung 1.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 30.09.2020 | 30.09.2020 | 31.03.2021 |
UTILMD AHB WiM 3.1a | 01.04.2020 | 31.03.2021 |
UTILMD AHB WiM 3.1a Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 10.06.2020 | 10.06.2020 | 31.03.2021 |
UTILTS MIG 1.0 | 01.12.2019 | 31.03.2021 |
UTILTS AHB 1.0 | 01.12.2019 | 31.03.2021 |
UTILTS AHB 1.0 Konsolidierte Lesefassung mit Fehlerkorrekturen Stand: 02.10.2019 | 01.12.2019 | 31.03.2021 |